@@ -15,25 +15,29 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
+
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 $VERSION = eval $VERSION;
 
+
 ## Load our modules
 
 use IO::Socket::INET;
 use Time::HiRes qw( gettimeofday );
 
+
 ## Handle importing/exporting of symbols
 
 use base qw( Exporter );
 our @EXPORT_OK  = qw ( getSNTPTime );
 
+
 =head1 SYNOPSIS
 
 The Net::SNTP::Client - Perl module retrieves the time from an NTP or 
@@ -55,6 +59,7 @@ The module sends a UDP packet formated according to
  to a human readable form and also calculated the roundtrip delay 
  d and system clock offset t, based on the decoded data.
 
+
 =head1 DESCRIPTION
 
 This module exports a single method (getSNTPTime) and returns
@@ -65,6 +70,7 @@ This module exports a single method (getSNTPTime) and returns
  further processing or manipulation according to the user needs.
  Maximum accuracy down to nano seconds can only be achieved on LinuxOS.
 
+
 =over 4
 
 =item * HOSTNAME
@@ -80,6 +86,13 @@ This module exports a single method (getSNTPTime) and returns
     NTP port on the server side (e.g. -port => 123456).
 
 
+=item * TIMEOUT
+
+    -timeOut: By default the time out is set to 10 seconds. The user
+    has the option to overwite the time out input option based on the
+    expected connection time (e.g. timeOut => 15).
+
+
 =item * RFC4330 OUTPUT
 
     -RFC4330: This is an optional way to produce an easy visual
@@ -94,12 +107,14 @@ This module exports a single method (getSNTPTime) and returns
     the captured data. Expected input is a string, integer or boolean
     in the form (0 or 1).
 
+
 =back
 
 =head1 SUBROUTINES/METHODS
 
   my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
 
+
 =cut
 
 ## Define constands
@@ -107,6 +122,7 @@ This module exports a single method (getSNTPTime) and returns
 use constant {
     TRUE             => 1,
     FALSE            => 0,
+    TIMEOUT          => 10,
     MAXBYTES         => 512,
     UNIX_EPOCH       => 2208988800,
     MIN_UDP_PORT     => 1,
@@ -118,7 +134,8 @@ use constant {
 
   my %hashInput = (
       -hostname      => $hostname,    # hostnmae or IP
-      -port          => $port,        # default NTP port 123 
+      -port          => $port,        # default NTP port 123
+      -timeOut       => $timeOut,     # default 10
       -RFC4330       => $RFC4330,     # default 0
       -clearScreen   => $clearScreen, # default 0
       );
@@ -128,7 +145,8 @@ use constant {
 This module exports a single method - getSNTPTime and an error
  string in case of an error or a faulty operation. It expects a
  hash as an input. The input can have four different hash
- keys (-hostname, port, RFC4330 and -clearScreen). 
+ keys (-hostname, port, RFC4330 and -clearScreen).
+
 
 =cut
 
@@ -139,6 +157,7 @@ sub getSNTPTime {
     return ($error = "Not defined key(s)", \%moduleInput) if (_checkHashKeys(%moduleInput));
     return ($error = "Not defined Hostname", \%moduleInput) if (!$moduleInput{-hostname});
     return ($error = "Not correct port number", \%moduleInput) if (_verifyPort($moduleInput{-port}));
+    return ($error = "Not correct timeOut input", \%moduleInput) if (_verifyNumericInput($moduleInput{-timeOut}));
     return ($error = "Not correct RFC4330 input", \%moduleInput) if (_verifyBoolean($moduleInput{-RFC4330}));
     return ($error = "Not correct clearScreen input", \%moduleInput) if (_verifyBoolean($moduleInput{-clearScreen}));
 
@@ -203,11 +222,11 @@ sub getSNTPTime {
     };
     return ($error = "Problem While Sending '$!'", \%moduleInput) if ( $@ && $@ =~ /Error Sending/ );
 
-    my $TIMEOUT = 20;
+    $moduleInput{-timeOut} = TIMEOUT if ( !defined $moduleInput{-timeOut});
     my $rcvSntpPacket = undef;
     eval {
 	local $SIG{ALRM} = sub { die "Error Timeout"; };
-	alarm($TIMEOUT);
+	alarm($moduleInput{-timeOut});
 	$client_socket->recv( $rcvSntpPacket , MAXBYTES )
 	    or die "Error Receiving";
 	alarm(0)
@@ -392,24 +411,32 @@ sub getSNTPTime {
 }
 
 sub _checkHashKeys {
-    my @keysToCompare = ( "-hostname", "-port", "-RFC4330", "-clearScreen" );
+    my @keysToCompare = ( "-hostname", "-port", "-timeOut", "-RFC4330", "-clearScreen" );
     my %hashInputToCompare = @_;
     my @hashInputKeysToCompare = keys %hashInputToCompare;
     
     my @differendKeys = _keyDifference(\@hashInputKeysToCompare, \@keysToCompare);
-    
     if (@differendKeys) { return TRUE } else { return FALSE };
 };
 
 sub _keyDifference {
-    my %hashdiff = map{ $_ => 1 } @{$_[1]}; 
-    return grep { !defined $hashdiff{$_} }  @{$_[0]};
+    my %hashdiff = map{ $_ => 1 } @{$_[1]};
+    return grep { !defined $hashdiff{$_} } @{$_[0]};
 }
 
+sub _verifyNumericInput {
+    my $numericInput = shift;
+    return FALSE if (!defined $numericInput);
+    if ( defined $numericInput && $numericInput =~ /^[0-9]+$/ && $numericInput > 0 ) {
+	return FALSE;
+    }
+    return TRUE;
+};
+
 sub _verifyPort {
     my $port = shift;
     return FALSE if (!defined $port);
-    if ( defined $port && $port =~ /^[0-9]+$/ ) {
+    if ( !_verifyNumericInput($port) ) {
 	if ( $port >= MIN_UDP_PORT && MAX_UDP_PORT >= $port ) {
 	    return FALSE;
 	}
@@ -420,7 +447,7 @@ sub _verifyPort {
 sub _verifyBoolean {
     my $input = shift;
     return FALSE if (!defined $input);
-    if ( defined $input && $input =~ /^[0-9]+$/ ) {
+    if ( !_verifyNumericInput($input) ) {
 	if ( $input eq "0" or $input eq "1" ) {
 	    return FALSE;
 	}
@@ -473,11 +500,11 @@ We use the L<Data::Dumper|http://search.cpan.org/~ilyam/Data-Dumper-2.121/Dumper
   my %hashInput = (
       -hostname      => "0.pool.ntp.org",
       -port          => 123,
+      -timeOutInput  => 10,
       -RFC4330       => 1,
       -clearScreen   => 1,
       );
 
-
   my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
 
   print Dumper $hashRefOutput;
@@ -488,16 +515,19 @@ DEPENDENCIES
 The module is implemented using IO::Socket::INET and Time::HiRes
  and requires both these modules to be installed.
 
+
 =head1 AUTHOR
 
 Athanasios Garyfalos, C<< <garyfalos at cpan.org> >>
 
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-net-sntp-client at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-SNTP-Client>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -506,6 +536,7 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
+
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -601,7 +632,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 15.0  2015/08/03 11:04:31 am  Thanos
+Revision 16.0  2015/08/06 11:58:31 pm  Thanos
 
 =cut
 
